summaryrefslogtreecommitdiffstats
path: root/pyuic3/form.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-14 21:12:44 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-14 21:12:44 -0600
commite87fff3247e64b4e9509be991a8f2d6bd4ccfacc (patch)
tree71a3198fc141420d65eefa7036159af85894cf7d /pyuic3/form.cpp
parent06500cd8e9be747a323920c9475fba0e6618d2de (diff)
downloadpytqt-e87fff3247e64b4e9509be991a8f2d6bd4ccfacc.tar.gz
pytqt-e87fff3247e64b4e9509be991a8f2d6bd4ccfacc.zip
Update various qt function definitions and static methods for tqt3
Diffstat (limited to 'pyuic3/form.cpp')
-rw-r--r--pyuic3/form.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/pyuic3/form.cpp b/pyuic3/form.cpp
index 6aa5aa5..1e5a81e 100644
--- a/pyuic3/form.cpp
+++ b/pyuic3/form.cpp
@@ -30,13 +30,13 @@
#define NO_STATIC_COLORS
#include <globaldefs.h>
-#if QT_VERSION < 0x030100
+#if TQT_VERSION < 0x030100
#include <zlib.h>
#endif
static TQByteArray unzipXPM( TQString data, ulong& length )
{
-#if QT_VERSION >= 0x030100
+#if TQT_VERSION >= 0x030100
const int lengthOffset = 4;
int baSize = data.length() / 2 + lengthOffset;
uchar *ba = new uchar[ baSize ];
@@ -55,13 +55,13 @@ static TQByteArray unzipXPM( TQString data, ulong& length )
r += l - 'a' + 10;
ba[ i ] = r;
}
// qUncompress() expects the first 4 bytes to be the expected length of the
// uncompressed data
ba[0] = ( length & 0xff000000 ) >> 24;
ba[1] = ( length & 0x00ff0000 ) >> 16;
ba[2] = ( length & 0x0000ff00 ) >> 8;
ba[3] = ( length & 0x000000ff );
- TQByteArray baunzip = qUncompress( ba, baSize );
+ TQByteArray baunzip = tqUncompress( ba, baSize );
delete[] ba;
return baunzip;
#else
@@ -395,7 +395,7 @@ void Uic::createFormImpl( const TQDomElement &e )
}
out << endl;
} else if ( externPixmaps ) {
-#if QT_VERSION >= 0x030100
+#if TQT_VERSION >= 0x030100
pixmapLoaderFunction = "TQPixmap.fromMimeSource";
#else
out << indent << "def uic_load_pixmap_" << objName << "(name):" << endl;
@@ -55,13 +55,13 @@ static TQByteArray unzipXPM( TQString data, ulong& length )
ba[ i ] = r;
}
- // qUncompress() expects the first 4 bytes to be the expected length of the
+ // tqUncompress() expects the first 4 bytes to be the expected length of the
// uncompressed data
ba[0] = ( length & 0xff000000 ) >> 24;